////////////////////////////////////////////////////////////////////////////////////////
//
// Socket
// Copyright (C) 2000  Thierry Tremblay
//
// http://frogengine.net-connect.net/
//
////////////////////////////////////////////////////////////////////////////////////////

#include "pop3.h"



////////////////////////////////////////////////////////////////////////////////////////
//
// POP3Protocol
//
////////////////////////////////////////////////////////////////////////////////////////

POP3Protocol::POP3Protocol()
:  m_socket( AF_INET, SOCK_STREAM, IPPROTO_TCP ),
   m_stream( m_socket.GetIOStream() )
{
}



POP3Protocol::~POP3Protocol()
{
}


      
bool POP3Protocol::Close()
{
   return m_socket.Close();
}



bool POP3Protocol::GetNbMessages( int* pNbMessage, int* pTotalSize )
{
   m_stream << "STAT\r" << std::endl;
   m_stream.getline( m_buffer, sizeof(m_buffer) );
   if (!LastCommandOK())
      return false;

   if (sscanf( m_buffer, "+OK %d %d", pNbMessage, pTotalSize ) != 2)
      return false;

   return true;
}



bool POP3Protocol::LastCommandOK()
{
   return strncmp( m_buffer, "+OK", 3 ) == 0;
}



bool POP3Protocol::Login( const char* szUser, const char* szPassword )
{
   m_stream << "USER " << szUser << "\r" << std::endl;
   m_stream.getline( m_buffer, sizeof(m_buffer) );
   if (!LastCommandOK())
      return false;

   m_stream << "PASS " << szPassword << "\r" << std::endl;
   m_stream.getline( m_buffer, sizeof(m_buffer) );
   if (!LastCommandOK())
      return false;

   return true;
}



bool POP3Protocol::Open( const char* szHost, int port )
{
   if (!m_socket.Connect( InternetAddress( szHost, 110 )) )
      return false;

   m_socket.SetReceiveTimeout( 10 );

   m_stream.getline( m_buffer, sizeof(m_buffer) );
   if (!LastCommandOK())
   {
      m_socket.Close();
      return false;
   }

   return true;
}


bool POP3Protocol::Quit()
{
   m_stream << "QUIT\r" << std::endl;
   m_stream.getline( m_buffer, sizeof(m_buffer) );
   if (!LastCommandOK())
   {
      m_socket.Close();
      return false;
   }

   return true;
}